@@ -5,7 +5,7 @@ import typing
 from collections.abc import Sequence
 from typing import Any
 
-from iker.common.utils.typeutils import is_identical_type, type_origin
+from iker.common.utils.typeutils import is_identical_type
 
 __all__ = [
     "ParserTreeNode",
@@ -67,9 +67,8 @@ class ParserTree(object):
         return last_node.parser
 
     def parse_args(self, args: list[str] | None = None) -> tuple[list[str], argparse.Namespace]:
-        # Before Python 3.12 the 'exit_on_error' attribute does not take effect properly
+        # Before Python 3.12 the `exit_on_error` attribute does not take effect properly
         # if unknown arguments encountered. We have to employ this workaround
-        # TODO: remove this workaround when bumping the Python versions to above Python 3.12
         if sys.version_info < (3, 12):
             if self.root_node.parser.exit_on_error:
                 known_args_namespace = self.root_node.parser.parse_args(args)
@@ -122,8 +121,8 @@ def make_argparse(func, parser: argparse.ArgumentParser = None) -> argparse.Argu
     if parser is None:
         parser = argparse.ArgumentParser()
 
-    def is_type_of(t: type, *types) -> bool:
-        return any(is_identical_type(t, type_) for type_ in types)
+    def is_type_of(a: Any, *bs) -> bool:
+        return any(is_identical_type(a, b, strict_optional=False, covariant=True) for b in bs)
 
     sig = inspect.signature(func)
     for name, param in sig.parameters.items():
@@ -132,18 +131,18 @@ def make_argparse(func, parser: argparse.ArgumentParser = None) -> argparse.Argu
 
         if param.annotation is None:
             arg_type = str
-        elif is_type_of(param.annotation, str, str | None, list[str], Sequence[str]):
+        elif is_type_of(param.annotation, str, Sequence[str]):
             arg_type = str
-        elif is_type_of(param.annotation, int, int | None, list[int], Sequence[int]):
+        elif is_type_of(param.annotation, int, Sequence[int]):
             arg_type = int
-        elif is_type_of(param.annotation, float, float | None, list[float], Sequence[float]):
+        elif is_type_of(param.annotation, float, Sequence[float]):
             arg_type = float
-        elif is_type_of(param.annotation, bool, bool | None, list[bool], Sequence[bool]):
+        elif is_type_of(param.annotation, bool, Sequence[bool]):
             arg_type = bool
         else:
             arg_type = str
 
-        arg_action = "append" if type_origin(param.annotation) in {list, Sequence} else None
+        arg_action = "append" if typing.get_origin(param.annotation) in {list, Sequence} else None
         arg_default = None if param.default is inspect.Parameter.empty else param.default
 
         if isinstance(arg_default, ArgParseSpec):
