@@ -3,6 +3,7 @@ import dataclasses
 import urllib.parse
 from typing import Any
 
+import packaging.version
 import psycopg
 import pymysql
 import sqlalchemy
@@ -90,10 +91,18 @@ class ConnectionMaker(object):
     def make_session(self, **kwargs) -> contextlib.AbstractContextManager[sqlalchemy.orm.Session]:
         return contextlib.closing(sqlalchemy.orm.sessionmaker(self.engine, **{**self.session_opts, **kwargs})())
 
-    def create_model(self, orm_base: type[sqlalchemy.orm.DeclarativeBase]):
+    def create_model(self, orm_base):
+        if packaging.version.parse(sqlalchemy.__version__) >= packaging.version.parse("2"):
+            if not isinstance(orm_base, type) or not issubclass(orm_base, sqlalchemy.orm.DeclarativeBase):
+                raise TypeError("not a subclass of 'sqlalchemy.orm.DeclarativeBase'")
+
         orm_base.metadata.create_all(self.engine)
 
-    def drop_model(self, orm_base: type[sqlalchemy.orm.DeclarativeBase]):
+    def drop_model(self, orm_base):
+        if packaging.version.parse(sqlalchemy.__version__) >= packaging.version.parse("2"):
+            if not isinstance(orm_base, type) or not issubclass(orm_base, sqlalchemy.orm.DeclarativeBase):
+                raise TypeError("not a subclass of 'sqlalchemy.orm.DeclarativeBase'")
+
         orm_base.metadata.drop_all(self.engine)
 
     def execute(self, sql: str, **params):
@@ -133,17 +142,19 @@ class ConnectionMaker(object):
 DBAdapter = ConnectionMaker
 
 
-def orm_to_dict(orm: sqlalchemy.orm.DeclarativeBase, exclude: set[str] = None) -> dict[str, Any]:
-    if not isinstance(orm, sqlalchemy.orm.DeclarativeBase):
-        raise TypeError('not a SQLAlchemy ORM declarative base')
+def orm_to_dict(orm, exclude: set[str] = None) -> dict[str, Any]:
+    if packaging.version.parse(sqlalchemy.__version__) >= packaging.version.parse("2"):
+        if not isinstance(orm, sqlalchemy.orm.DeclarativeBase):
+            raise TypeError("not an instance of 'sqlalchemy.orm.DeclarativeBase'")
 
     mapper = sqlalchemy.inspect(type(orm))
     return dict((c.key, getattr(orm, c.key)) for c in mapper.columns if c.key not in (exclude or set()))
 
 
-def orm_clone(orm: sqlalchemy.orm.DeclarativeBase, exclude: set[str] = None, no_autoincrement: bool = False):
-    if not isinstance(orm, sqlalchemy.orm.DeclarativeBase):
-        raise TypeError('not a SQLAlchemy ORM declarative base')
+def orm_clone(orm, exclude: set[str] = None, no_autoincrement: bool = False):
+    if packaging.version.parse(sqlalchemy.__version__) >= packaging.version.parse("2"):
+        if not isinstance(orm, sqlalchemy.orm.DeclarativeBase):
+            raise TypeError("not an instance of 'sqlalchemy.orm.DeclarativeBase'")
 
     mapper = sqlalchemy.inspect(type(orm))
     exclude = exclude or (set(c.key for c in mapper.columns if c.autoincrement is True) if no_autoincrement else set())
