@@ -23,7 +23,9 @@ __all__ = [
     "dt_utc_now",
     "dt_utc",
     "dt_to_ts",
+    "dt_to_ts_us",
     "dt_from_ts",
+    "dt_from_ts_us",
     "dt_parse",
     "dt_format",
     "dt_parse_iso",
@@ -152,6 +154,17 @@ def dt_utc(
     return datetime.datetime(year, month, day, hour, minute, second, microsecond, tzinfo=datetime.timezone.utc)
 
 
+def dt_to_td(dt: datetime.datetime) -> datetime.timedelta:
+    """
+    Returns corresponding timedelta of the given datetime
+
+    :param dt: the given datetime
+
+    :return: timedelta from POSIX epoch
+    """
+    return dt.replace(tzinfo=datetime.timezone.utc) - dt_utc_epoch()
+
+
 def dt_to_ts(dt: datetime.datetime) -> float:
     """
     Returns corresponding timestamp in seconds of the given datetime
@@ -160,7 +173,30 @@ def dt_to_ts(dt: datetime.datetime) -> float:
 
     :return: timestamp in seconds from POSIX epoch
     """
-    return (dt.replace(tzinfo=datetime.timezone.utc) - dt_utc_epoch()).total_seconds()
+    return dt_to_ts_us(dt) / 1.0e6
+
+
+def dt_to_ts_us(dt: datetime.datetime) -> int:
+    """
+    Returns corresponding timestamp in microseconds of the given datetime
+
+    :param dt: the given datetime
+
+    :return: timestamp in microseconds from POSIX epoch
+    """
+    td = dt_to_td(dt)
+    return (td.days * 86400 + td.seconds) * 1000000 + td.microseconds
+
+
+def dt_from_td(td: datetime.timedelta) -> datetime.datetime:
+    """
+    Returns corresponding datetime in UTC of the given timedelta
+
+    :param td: timedelta from POSIX epoch
+
+    :return: the given datetime in UTC
+    """
+    return dt_utc_epoch() + td
 
 
 def dt_from_ts(ts: float) -> datetime.datetime:
@@ -171,11 +207,26 @@ def dt_from_ts(ts: float) -> datetime.datetime:
 
     :return: the given datetime in UTC
     """
-    return datetime.datetime.fromtimestamp(ts, tz=datetime.timezone.utc)
+    return dt_from_ts_us(round(ts * 1.0e6))
 
 
-basic_tz_regexp = re.compile(r"([+-])(\d{2})(\d{2})")
-extended_tz_regexp = re.compile(r"([+-])(\d{2}):(\d{2})")
+def dt_from_ts_us(ts: int) -> datetime.datetime:
+    """
+    Returns corresponding datetime in UTC of the given timestamp in microseconds
+
+    :param ts: timestamp in microseconds from POSIX epoch
+
+    :return: the given datetime in UTC
+    """
+    return dt_from_td(datetime.timedelta(microseconds=ts))
+
+
+basic_date_regex: re.Pattern[str] = re.compile(r"(\d{4})(\d{2})(\d{2})")
+extended_date_regex: re.Pattern[str] = re.compile(r"(\d{4})-(\d{2})-(\d{2})")
+basic_time_regex: re.Pattern[str] = re.compile(r"T(\d{2})(\d{2})(\d{2})(\.\d{1,6})?")
+extended_time_regex: re.Pattern[str] = re.compile(r"T(\d{2}):(\d{2}):(\d{2})(\.\d{1,6})?")
+basic_tz_regexp: re.Pattern[str] = re.compile(r"([+-])(\d{2})(\d{2})")
+extended_tz_regexp: re.Pattern[str] = re.compile(r"([+-])(\d{2}):(\d{2})")
 
 
 def dt_parse(dt_str: str, fmt_str: str | Sequence[str]) -> datetime.datetime | None:
@@ -191,7 +242,7 @@ def dt_parse(dt_str: str, fmt_str: str | Sequence[str]) -> datetime.datetime | N
         return None
 
     if isinstance(fmt_str, str):
-        for tz_directive in ["%z", "%:z", "%Z"]:
+        for tz_directive in ["%z", "%:z"]:
             if tz_directive in fmt_str:
                 if tz_directive == "%:z":
                     # Replaces ISO 8601 timezone format "%:z" (e.g., "+01:00") with "%z" (e.g., "+0100")
