@@ -1,7 +1,7 @@
 import functools
 import itertools
 from collections.abc import Callable, Generator, Iterable, Iterator, Sequence, Sized
-from typing import Generic, Self, TypeVar
+from typing import Generic, TypeVar
 
 __all__ = [
     "head",
@@ -9,7 +9,9 @@ __all__ = [
     "last",
     "last_or_none",
     "tail",
+    "tail_iter",
     "init",
+    "init_iter",
     "grouped",
     "deduped",
     "batch_yield",
@@ -22,9 +24,9 @@ __all__ = [
 ]
 
 T = TypeVar("T")
-K = TypeVar("K")
-U = TypeVar("U")
-V = TypeVar("V")
+KT = TypeVar("KT")
+VT = TypeVar("VT")
+TT = TypeVar("TT")
 Tco = TypeVar("Tco", covariant=True)
 
 
@@ -55,16 +57,37 @@ def tail(ms: Sequence[T]) -> Sequence[T]:
     return ms[1:]
 
 
+def tail_iter(ms: Iterable[T]) -> Generator[T, None, None]:
+    it = iter(ms)
+    try:
+        next(it)
+        while True:
+            yield next(it)
+    except StopIteration:
+        return
+
+
 def init(ms: Sequence[T]) -> Sequence[T]:
     return ms[:-1]
 
 
+def init_iter(ms: Iterable[T]) -> Generator[T, None, None]:
+    it = iter(ms)
+    try:
+        prev = next(it)
+    except StopIteration:
+        return
+    for this in it:
+        yield prev
+        prev = this
+
+
 def grouped(
     ms: Sequence[T],
-    key_func: Callable[[T], K],
+    key_func: Callable[[T], KT],
     keys_ordered: bool = False,
     values_only: bool = False,
-) -> list[tuple[K, list[T]]] | list[list[T]]:
+) -> list[tuple[KT, list[T]]] | list[list[T]]:
     """
     Groups the given list of elements according to key generator function
 
@@ -76,7 +99,7 @@ def grouped(
     """
     if ms is None or len(ms) == 0:
         return []
-    grouped_ms: dict[K, list[T]] = {}
+    grouped_ms: dict[KT, list[T]] = {}
     for m in ms:
         k = key_func(m)
         grouped_ms.setdefault(k, []).append(m)
@@ -95,7 +118,7 @@ def deduped(ms: Sequence[T], comp_func: Callable[[T, T], bool]) -> list[T]:
     if ms is None or len(ms) == 0:
         return []
     deduped_ms: list[T] = [head(ms)]
-    for m in tail(ms):
+    for m in tail_iter(ms):
         if not comp_func(last(deduped_ms), m):
             deduped_ms.append(m)
     return deduped_ms
@@ -134,7 +157,7 @@ def chunk(ms: Sequence[T], chunk_func: Callable[[Sequence[T], T], bool], exclusi
     if ms is None or len(ms) == 0:
         return []
     chunks: list[list[T]] = [[head(ms)]]
-    for m in tail(ms):
+    for m in tail_iter(ms):
         if chunk_func(last(chunks), m):
             if exclusive_end:
                 last(chunks).append(m)
@@ -148,7 +171,7 @@ def chunk_between(ms: Sequence[T], chunk_func: Callable[[T, T], bool], exclusive
     return chunk(ms, lambda x, y: chunk_func(last(x), y), exclusive_end)
 
 
-def chunk_with_key(ms: Sequence[T], key_func: Callable[[T], K], exclusive_end: bool = False) -> list[list[T]]:
+def chunk_with_key(ms: Sequence[T], key_func: Callable[[T], KT], exclusive_end: bool = False) -> list[list[T]]:
     return chunk_between(ms, lambda x, y: key_func(x) != key_func(y), exclusive_end)
 
 
@@ -174,7 +197,7 @@ def merge_chunks(
     def stateful_reducer(a: Sequence[T], b: Sequence[T]) -> Sequence[T]:
         if merge_func(a, b):
             if drop_exclusive_end:
-                return list(itertools.chain(init(a), b))
+                return list(itertools.chain(init_iter(a), b))
             return list(itertools.chain(a, b))
         else:
             merged_chunks.append(list(a))
@@ -185,8 +208,11 @@ def merge_chunks(
     return merged_chunks
 
 
+SeqT = TypeVar("SeqT", bound="Seq")
+
+
 class Seq(Generic[Tco], Sequence[Tco], Sized):
-    def __init__(self, data: Iterable[Tco] | Self):
+    def __init__(self, data: Iterable[Tco] | SeqT):
         if isinstance(data, Seq):
             self.data = data.data
         elif isinstance(data, Iterable):
@@ -202,14 +228,14 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
     def empty(self) -> bool:
         return self.size == 0
 
-    def __add__(self, other: Self) -> Self:
+    def __add__(self: SeqT, other: SeqT) -> SeqT:
         return self.concat(other)
 
-    def __getitem__(self, item):
+    def __getitem__(self: SeqT, item) -> SeqT:
         if isinstance(item, slice):
-            return Seq(self.data[item])
+            return type(self)(self.data[item])
         elif isinstance(item, int):
-            return Seq([self.data[item]])
+            return type(self)([self.data[item]])
         raise ValueError("unsupported index type")
 
     def __len__(self) -> int:
@@ -230,28 +256,28 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
     def count_if(self, func: Callable[[Tco], bool]):
         return sum(1 for item in self.data if func(item))
 
-    def concat(self, other: Self) -> Self:
-        return Seq(self.data + other.data)
+    def concat(self: SeqT, other: SeqT) -> SeqT:
+        return type(self)(self.data + other.data)
 
-    def take_left(self, n: int) -> Self:
+    def take_left(self: SeqT, n: int) -> SeqT:
         if n <= 0:
-            return Seq([])
+            return type(self)([])
         return self[:n]
 
-    def take_right(self, n: int) -> Self:
+    def take_right(self: SeqT, n: int) -> SeqT:
         if n <= 0:
-            return Seq([])
+            return type(self)([])
         return self[-n:]
 
     take = take_left
 
-    def reverse(self) -> Self:
-        return Seq(reversed(self.data))
+    def reverse(self: SeqT) -> SeqT:
+        return type(self)(reversed(self.data))
 
-    def distinct(self) -> Self:
-        return Seq(list(set(self.data)))
+    def distinct(self: SeqT) -> SeqT:
+        return type(self)(sorted(set(self.data)))
 
-    def scan_left(self, zero: U | None, func: Callable[[U, Tco], U]) -> "Seq[U]":
+    def scan_left(self, zero: TT | None, func: Callable[[TT, Tco], TT]) -> "Seq[TT]":
         def scan():
             accum = zero
             for elem in self.data:
@@ -260,7 +286,7 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
 
         return Seq(scan())
 
-    def scan_right(self, zero: U | None, func: Callable[[U, Tco], U]) -> "Seq[U]":
+    def scan_right(self, zero: TT | None, func: Callable[[TT, Tco], TT]) -> "Seq[TT]":
         def scan():
             accum = zero
             for elem in reversed(self.data):
@@ -271,41 +297,41 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
 
     scan = scan_left
 
-    def map(self, func: Callable[[Tco], U]) -> "Seq[U]":
+    def map(self, func: Callable[[Tco], TT]) -> "Seq[TT]":
         return self.scan(None, lambda x, y: func(y))
 
-    def fold_left(self, zero: U | None, func: Callable[[U, Tco], U]) -> "Seq[U]":
+    def fold_left(self, zero: TT | None, func: Callable[[TT, Tco], TT]) -> "Seq[TT]":
         if self.empty:
             return Seq([]) if zero is None else Seq([zero])
         data = self.data if zero is None else [zero] + self.data
         accum = head(data)
-        for elem in tail(data):
+        for elem in tail_iter(data):
             accum = func(accum, elem)
         return Seq([accum])
 
-    def fold_right(self, zero: U | None, func: Callable[[U, Tco], U]) -> "Seq[U]":
+    def fold_right(self, zero: TT | None, func: Callable[[TT, Tco], TT]) -> "Seq[TT]":
         if self.empty:
             return Seq([]) if zero is None else Seq([zero])
         data = self.data if zero is None else self.data + [zero]
         accum = last(data)
-        for elem in reversed(init(data)):
+        for elem in tail_iter(reversed(data)):
             accum = func(accum, elem)
         return Seq([accum])
 
     fold = fold_left
 
-    def reduce(self, func: Callable[[Tco, Tco], Tco]) -> Self:
-        return self.fold(None, lambda x, y: func(x, y))
+    def reduce(self: SeqT, func: Callable[[Tco, Tco], Tco]) -> SeqT:
+        return type(self)(self.fold(None, lambda x, y: func(x, y)))
 
-    def max(self, func: Callable[[Tco, Tco], bool] = None) -> Self:
+    def max(self: SeqT, func: Callable[[Tco, Tco], bool] = None) -> SeqT:
         func = func or (lambda x, y: x > y)
         return self.reduce(lambda x, y: x if func(x, y) else y)
 
-    def min(self, func: Callable[[Tco, Tco], bool] = None) -> Self:
+    def min(self: SeqT, func: Callable[[Tco, Tco], bool] = None) -> SeqT:
         func = func or (lambda x, y: x < y)
         return self.reduce(lambda x, y: x if func(x, y) else y)
 
-    def group(self, func: Callable[[Tco], K]) -> "Seq[tuple[K, list[Tco]]]":
+    def group(self, func: Callable[[Tco], KT]) -> "Seq[tuple[KT, list[Tco]]]":
         return Seq(grouped(self.data, key_func=func, keys_ordered=True))
 
     def keys(self):
@@ -317,13 +343,13 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
     def swap(self):
         return Seq((value, key) for key, value in self.data)
 
-    def map_keys(self, func: Callable[[Tco], U]) -> Self:
+    def map_keys(self, func: Callable[[Tco], TT]):
         return Seq((func(key), value) for key, value in self.data)
 
-    def map_values(self, func: Callable[[Tco], U]) -> Self:
+    def map_values(self, func: Callable[[Tco], TT]):
         return Seq((key, func(value)) for key, value in self.data)
 
-    def flat_map(self, func: Callable[[Tco], Iterable[U]]) -> "Seq[U]":
+    def flat_map(self, func: Callable[[Tco], Iterable[TT]]) -> "Seq[TT]":
         data = []
         for d in self.data:
             data.extend(func(d))
@@ -332,31 +358,31 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
     def flatten(self):
         return self.flat_map(lambda x: list(x))
 
-    def group_map(self, group_func: Callable[[Tco], K], map_func: Callable[[Tco], U]) -> "Seq[tuple[K, list[U]]]":
+    def group_map(self, group_func: Callable[[Tco], KT], map_func: Callable[[Tco], TT]) -> "Seq[tuple[KT, list[TT]]]":
         return self.group(group_func).map_values(lambda x: list(map(map_func, x)))
 
-    def filter(self, func: Callable[[Tco], bool]) -> Self:
-        return Seq(filter(func, self.data))
+    def filter(self: SeqT, func: Callable[[Tco], bool]) -> SeqT:
+        return type(self)(filter(func, self.data))
 
-    def filter_not(self, func: Callable[[Tco], bool]) -> Self:
+    def filter_not(self: SeqT, func: Callable[[Tco], bool]) -> SeqT:
         return self.filter(lambda x: not func(x))
 
-    def sort(self, func: Callable[[Tco], K]) -> Self:
-        return Seq(sorted(self.data, key=func))
+    def sort(self: SeqT, func: Callable[[Tco], KT]) -> SeqT:
+        return type(self)(sorted(self.data, key=func))
 
-    def head(self) -> Self:
-        return Seq([head(self.data)])
+    def head(self: SeqT) -> SeqT:
+        return type(self)([head(self.data)])
 
-    def last(self) -> Self:
-        return Seq([last(self.data)])
+    def last(self: SeqT) -> SeqT:
+        return type(self)([last(self.data)])
 
-    def init(self) -> Self:
-        return Seq(init(self.data))
+    def init(self: SeqT) -> SeqT:
+        return type(self)(init_iter(self.data))
 
-    def tail(self) -> Self:
-        return Seq(tail(self.data))
+    def tail(self: SeqT) -> SeqT:
+        return type(self)(tail_iter(self.data))
 
-    def foreach(self, func: Callable[[Tco], None]) -> Self:
+    def foreach(self: SeqT, func: Callable[[Tco], None]) -> SeqT:
         for elem in self.data:
             func(elem)
         return self
@@ -367,16 +393,16 @@ class Seq(Generic[Tco], Sequence[Tco], Sized):
     def forall(self, func: Callable[[Tco], bool]) -> "Seq[bool]":
         return Seq([all(map(func, self.data))])
 
-    def union(self, other: Self) -> Self:
-        return Seq(list(set(self.data).union(set(other.data))))
+    def union(self: SeqT, other: SeqT) -> SeqT:
+        return type(self)(sorted(set(self.data).union(set(other.data))))
 
-    def intersect(self, other: Self) -> Self:
-        return Seq(list(set(self.data).intersection(set(other.data))))
+    def intersect(self: SeqT, other: SeqT) -> SeqT:
+        return type(self)(sorted(set(self.data).intersection(set(other.data))))
 
-    def zip(self, other: "Seq[U]") -> "Seq[tuple[Tco, U]]":
+    def zip(self, other: "Seq[TT]") -> "Seq[tuple[Tco, TT]]":
         return Seq(zip(self.data, other.data))
 
-    def zip_fill(self, other: "Seq[U]", fill: Tco | U | None = None) -> "Seq[tuple[Tco, U]]":
+    def zip_fill(self, other: "Seq[TT]", fill: Tco | TT | None = None) -> "Seq[tuple[Tco, TT]]":
         return Seq(itertools.zip_longest(self.data, other.data, fillvalue=fill))
 
 
