@@ -14,8 +14,7 @@ from iker_tests.docker_fixtures import MockedDockerContainer, MockedDockerImage
 
 @ddt.ddt
 class DockerUtilsTest(unittest.TestCase):
-
-    @ddt.data(
+    data_image_name = [
         (
             "ubuntu",
             ImageName(None, None, ["ubuntu"], None),
@@ -124,7 +123,9 @@ class DockerUtilsTest(unittest.TestCase):
             "hub.docker.com:8080",
             "docker-hub/canonical/ubuntu",
         ),
-    )
+    ]
+
+    @ddt.idata(data_image_name)
     @ddt.unpack
     def test_image_name(self, image_name_str, image_name, registry, repository):
         actual = ImageName.parse(image_name_str)
@@ -139,7 +140,7 @@ class DockerUtilsTest(unittest.TestCase):
         self.assertEqual(registry, actual.registry)
         self.assertEqual(repository, actual.repository)
 
-    @ddt.data(
+    data_image_name__bad_names = [
         ("Ubuntu",),
         ("UBUNTU",),
         ("ubuntu.",),
@@ -154,7 +155,9 @@ class DockerUtilsTest(unittest.TestCase):
         (
             "ubuntu:tag_is_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_too_long",
         ),
-    )
+    ]
+
+    @ddt.idata(data_image_name__bad_names)
     @ddt.unpack
     def test_image_name__bad_names(self, image_name_str):
         self.assertIsNone(ImageName.parse(image_name_str))
@@ -211,11 +214,13 @@ class DockerUtilsTest(unittest.TestCase):
                                                                             forcerm=True,
                                                                             nocache=True)
 
-    @ddt.data(
+    data_docker_build_image__with_exception = [
         (docker.errors.BuildError("dummy reason", iter([{"dummy-log-key": "dummy-log-value"}])),),
         (docker.errors.APIError("dummy message"),),
         (Exception(),),
-    )
+    ]
+
+    @ddt.idata(data_docker_build_image__with_exception)
     @ddt.unpack
     def test_docker_build_image__with_exception(self, exception):
         with unittest.mock.patch("iker.common.utils.dockerutils.docker.DockerClient") as mock_docker_client:
@@ -251,11 +256,13 @@ class DockerUtilsTest(unittest.TestCase):
 
             mock_docker_client.return_value.images.get.assert_called_with("dummy_image")
 
-    @ddt.data(
+    data_docker_get_image__with_exception = [
         (docker.errors.ImageNotFound("dummy message"),),
         (docker.errors.APIError("dummy message"),),
         (Exception(),),
-    )
+    ]
+
+    @ddt.idata(data_docker_get_image__with_exception)
     @ddt.unpack
     def test_docker_get_image__with_exception(self, exception):
         with unittest.mock.patch("iker.common.utils.dockerutils.docker.DockerClient") as mock_docker_client:
@@ -303,11 +310,13 @@ class DockerUtilsTest(unittest.TestCase):
             mock_docker_client.return_value.images.get.assert_called_with("dummy_image")
             mock_docker_client.return_value.images.pull.assert_called_with("dummy_image")
 
-    @ddt.data(
+    data_docker_pull_image__with_exception = [
         (docker.errors.ImageNotFound("dummy message"),),
         (docker.errors.APIError("dummy message"),),
         (Exception(),),
-    )
+    ]
+
+    @ddt.idata(data_docker_pull_image__with_exception)
     @ddt.unpack
     def test_docker_pull_image__with_exception(self, exception):
         with unittest.mock.patch("iker.common.utils.dockerutils.docker.DockerClient") as mock_docker_client:
@@ -321,11 +330,13 @@ class DockerUtilsTest(unittest.TestCase):
             mock_docker_client.return_value.images.get.assert_not_called()
             mock_docker_client.return_value.images.pull.assert_called_with("dummy_image")
 
-    @ddt.data(
+    data_docker_pull_image__fallback_with_exception = [
         (docker.errors.ImageNotFound("dummy message"),),
         (docker.errors.APIError("dummy message"),),
         (Exception(),),
-    )
+    ]
+
+    @ddt.idata(data_docker_pull_image__fallback_with_exception)
     @ddt.unpack
     def test_docker_pull_image__fallback_with_exception(self, exception):
         with unittest.mock.patch("iker.common.utils.dockerutils.docker.DockerClient") as mock_docker_client:
@@ -417,7 +428,7 @@ class DockerUtilsTest(unittest.TestCase):
             mock_docker_container.stop_callee.assert_called_once()
             mock_docker_container.remove_callee.assert_called_once()
 
-    @ddt.data(
+    data_docker_run_detached__with_exception_on_wait = [
         (requests.exceptions.ReadTimeout(),),
         (docker.errors.ImageNotFound("dummy message"),),
         (
@@ -429,7 +440,9 @@ class DockerUtilsTest(unittest.TestCase):
         ),
         (docker.errors.APIError("dummy message"),),
         (Exception(),),
-    )
+    ]
+
+    @ddt.idata(data_docker_run_detached__with_exception_on_wait)
     @ddt.unpack
     def test_docker_run_detached__with_exception_on_wait(self, exception):
         with unittest.mock.patch("iker.common.utils.dockerutils.docker.DockerClient") as mock_docker_client:
@@ -473,7 +486,7 @@ class DockerUtilsTest(unittest.TestCase):
             mock_docker_container.stop_callee.assert_called_once()
             mock_docker_container.remove_callee.assert_called_once()
 
-    @ddt.data(
+    data_docker_run_detached__with_exception_on_stop = [
         (docker.errors.ImageNotFound("dummy message"),),
         (
             docker.errors.ContainerError("dummy container",
@@ -483,7 +496,9 @@ class DockerUtilsTest(unittest.TestCase):
                                          "dummy stderr"),
         ),
         (docker.errors.APIError("dummy message"),),
-    )
+    ]
+
+    @ddt.idata(data_docker_run_detached__with_exception_on_stop)
     @ddt.unpack
     def test_docker_run_detached__with_exception_on_stop(self, exception):
         with unittest.mock.patch("iker.common.utils.dockerutils.docker.DockerClient") as mock_docker_client:
