@@ -4,7 +4,7 @@ import ddt
 
 from iker.common.utils.dtutils import basic_format, extended_format, iso_format
 from iker.common.utils.dtutils import dt_format, dt_format_iso, dt_parse, dt_parse_iso
-from iker.common.utils.dtutils import dt_from_ts, dt_to_ts
+from iker.common.utils.dtutils import dt_from_ts, dt_from_ts_us, dt_to_ts, dt_to_ts_us
 from iker.common.utils.dtutils import dt_utc
 from iker.common.utils.dtutils import dt_utc_epoch, dt_utc_max, dt_utc_min
 
@@ -63,6 +63,34 @@ class DtUtilsTest(unittest.TestCase):
     def test_dt_to_ts(self, data, expect):
         self.assertEqual(expect, dt_to_ts(data))
 
+    data_dt_to_ts_us = [
+        (dt_utc(1970, 1, 1), 0),
+        (dt_utc(1969, 12, 31, 23, 59, 59), -1000000),
+        (dt_utc(1969, 12, 31, 23, 59, 59, 1), -999999),
+        (dt_utc(1969, 12, 31, 23, 59, 59, 1000), -999000),
+        (dt_utc(1969, 12, 31, 23, 59, 59, 999999), -1),
+        (dt_utc(1970, 1, 1, 0, 0, 1), 1000000),
+        (dt_utc(1970, 1, 1, 0, 0, 1, 1), 1000001),
+        (dt_utc(1970, 1, 1, 0, 0, 1, 1000), 1001000),
+        (dt_utc(1970, 1, 1, 0, 0, 1, 999999), 1999999),
+        (dt_utc(1970, 1, 1, 0, 0, 0, 1), 1),
+        (dt_utc(1970, 1, 1, 0, 0, 0, 1000), 1000),
+        (dt_utc(1970, 1, 1, 0, 0, 0, 999999), 999999),
+        (dt_utc(2025, 1, 1, 0, 0, 0), 1735689600000000),
+        (dt_utc(2025, 1, 1, 0, 0, 0, 1), 1735689600000001),
+        (dt_utc(2025, 1, 1, 0, 0, 0, 1000), 1735689600001000),
+        (dt_utc(2025, 1, 1, 0, 0, 0, 999999), 1735689600999999),
+        (dt_utc(2100, 1, 1, 0, 0, 0), 4102444800000000),
+        (dt_utc(2100, 1, 1, 0, 0, 0, 1), 4102444800000001),
+        (dt_utc(2100, 1, 1, 0, 0, 0, 1000), 4102444800001000),
+        (dt_utc(2100, 1, 1, 0, 0, 0, 999999), 4102444800999999),
+    ]
+
+    @ddt.idata(data_dt_to_ts_us)
+    @ddt.unpack
+    def test_dt_to_ts_us(self, data, expect):
+        self.assertEqual(expect, dt_to_ts_us(data))
+
     data_dt_from_ts = [
         (0.0, dt_utc(1970, 1, 1)),
         (-1.0, dt_utc(1969, 12, 31, 23, 59, 59)),
@@ -91,6 +119,34 @@ class DtUtilsTest(unittest.TestCase):
     def test_dt_from_ts(self, data, expect):
         self.assertEqual(expect, dt_from_ts(data))
 
+    data_dt_from_ts_us = [
+        (0, dt_utc(1970, 1, 1)),
+        (-1000000, dt_utc(1969, 12, 31, 23, 59, 59)),
+        (-999999, dt_utc(1969, 12, 31, 23, 59, 59, 1)),
+        (-999000, dt_utc(1969, 12, 31, 23, 59, 59, 1000)),
+        (-1, dt_utc(1969, 12, 31, 23, 59, 59, 999999)),
+        (1000000, dt_utc(1970, 1, 1, 0, 0, 1)),
+        (1000001, dt_utc(1970, 1, 1, 0, 0, 1, 1)),
+        (1001000, dt_utc(1970, 1, 1, 0, 0, 1, 1000)),
+        (1999999, dt_utc(1970, 1, 1, 0, 0, 1, 999999)),
+        (1, dt_utc(1970, 1, 1, 0, 0, 0, 1)),
+        (1000, dt_utc(1970, 1, 1, 0, 0, 0, 1000)),
+        (999999, dt_utc(1970, 1, 1, 0, 0, 0, 999999)),
+        (1735689600000000, dt_utc(2025, 1, 1, 0, 0, 0)),
+        (1735689600000001, dt_utc(2025, 1, 1, 0, 0, 0, 1)),
+        (1735689600001000, dt_utc(2025, 1, 1, 0, 0, 0, 1000)),
+        (1735689600999999, dt_utc(2025, 1, 1, 0, 0, 0, 999999)),
+        (4102444800000000, dt_utc(2100, 1, 1, 0, 0, 0)),
+        (4102444800000001, dt_utc(2100, 1, 1, 0, 0, 0, 1)),
+        (4102444800001000, dt_utc(2100, 1, 1, 0, 0, 0, 1000)),
+        (4102444800999999, dt_utc(2100, 1, 1, 0, 0, 0, 999999)),
+    ]
+
+    @ddt.idata(data_dt_from_ts_us)
+    @ddt.unpack
+    def test_dt_from_ts_us(self, data, expect):
+        self.assertEqual(expect, dt_from_ts_us(data))
+
     data_dt_parse = [
         ("00010101T000000", basic_format(), dt_utc(1, 1, 1, 0, 0, 0)),
         ("00010101T000000.000000", basic_format(with_ms=True), dt_utc(1, 1, 1, 0, 0, 0)),
