@@ -15,27 +15,31 @@ class RandUtilsTest(unittest.TestCase):
         self.assertTrue(any(s for s in samples))
         self.assertTrue(any(not s for s in samples))
 
-    @ddt.data(
+    data_next_int = [
         (0, 1),
         (-1, 0),
         (-1, 1),
         (0, max_int()),
         (-max_int(), 0),
         (-max_int() // 2, max_int() // 2),
-    )
+    ]
+
+    @ddt.idata(data_next_int)
     @ddt.unpack
     def test_next_int(self, lo, hi):
         for _ in range(0, 100000):
             self.assertTrue(lo <= randomizer().next_int(lo, hi) < hi)
 
-    @ddt.data(
+    data_next_float = [
         (0.0, 1.0),
         (-1.0, 0.0),
         (-1.0, 1.0),
         (0.0, max_float()),
         (-max_float(), 0.0),
         (-max_float() * 0.5, max_float() * 0.5),
-    )
+    ]
+
+    @ddt.idata(data_next_float)
     @ddt.unpack
     def test_next_float(self, lo, hi):
         for _ in range(0, 100000):
