@@ -52,134 +52,136 @@ class S3UtilsTest(unittest.TestCase):
                 self.assertTrue(any(o.key == key for o in result))
                 self.assertEqual(s3_pull_text(client, "dummy-bucket", key), text)
 
-    @ddt.data(
+    data_s3_listfile = [
         (
-            "{res_dir}/unittest/shutils/",
+            "{res_dir}/unittest/s3utils/",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             [],
             [],
             0,
             [
-                "unittest/shutils/dir.baz/file.foo.bar",
-                "unittest/shutils/dir.baz/file.foo.baz",
-                "unittest/shutils/dir.baz/file.bar.baz",
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.baz",
-                "unittest/shutils/dir.foo/file.foo",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.baz",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.bar.baz",
-                "unittest/shutils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
+                "unittest/s3utils/dir.baz/file.foo.bar",
+                "unittest/s3utils/dir.baz/file.foo.baz",
+                "unittest/s3utils/dir.baz/file.bar.baz",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.baz",
+                "unittest/s3utils/dir.foo/file.foo",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.baz",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.bar.baz",
+                "unittest/s3utils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             [],
             [],
             0,
             [
-                "unittest/shutils/dir.baz/file.foo.bar",
-                "unittest/shutils/dir.baz/file.foo.baz",
-                "unittest/shutils/dir.baz/file.bar.baz",
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.baz",
-                "unittest/shutils/dir.foo/file.foo",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.baz",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.bar.baz",
-                "unittest/shutils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
+                "unittest/s3utils/dir.baz/file.foo.bar",
+                "unittest/s3utils/dir.baz/file.foo.baz",
+                "unittest/s3utils/dir.baz/file.bar.baz",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.baz",
+                "unittest/s3utils/dir.foo/file.foo",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.baz",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.bar.baz",
+                "unittest/s3utils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils/dir.foo",
+            "{res_dir}/unittest/s3utils/dir.foo",
             "dummy-bucket",
-            "unittest/shutils/dir.foo",
+            "unittest/s3utils/dir.foo",
             [],
             [],
             0,
             [
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.baz",
-                "unittest/shutils/dir.foo/file.foo",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.baz",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.bar.baz",
-                "unittest/shutils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.baz",
+                "unittest/s3utils/dir.foo/file.foo",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.baz",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.bar.baz",
+                "unittest/s3utils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils/dir.baz",
+            "{res_dir}/unittest/s3utils/dir.baz",
             "dummy-bucket",
-            "unittest/shutils/dir.baz",
+            "unittest/s3utils/dir.baz",
             [],
             [],
             0,
             [
-                "unittest/shutils/dir.baz/file.foo.bar",
-                "unittest/shutils/dir.baz/file.foo.baz",
-                "unittest/shutils/dir.baz/file.bar.baz",
+                "unittest/s3utils/dir.baz/file.foo.bar",
+                "unittest/s3utils/dir.baz/file.foo.baz",
+                "unittest/s3utils/dir.baz/file.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             ["*.foo", "*.bar"],
             ["*.foo.bar"],
             0,
             [
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.foo",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.foo",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             ["*.foo", "*.bar"],
             [],
             0,
             [
-                "unittest/shutils/dir.baz/file.foo.bar",
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.foo",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
+                "unittest/s3utils/dir.baz/file.foo.bar",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.foo",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             [],
             ["*.baz"],
             0,
             [
-                "unittest/shutils/dir.baz/file.foo.bar",
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.foo",
-                "unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
+                "unittest/s3utils/dir.baz/file.foo.bar",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.foo",
+                "unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils",
+            "unittest/s3utils",
             [],
             [],
             2,
             [
-                "unittest/shutils/dir.baz/file.foo.bar",
-                "unittest/shutils/dir.baz/file.foo.baz",
-                "unittest/shutils/dir.baz/file.bar.baz",
-                "unittest/shutils/dir.foo/file.bar",
-                "unittest/shutils/dir.foo/file.baz",
-                "unittest/shutils/dir.foo/file.foo",
+                "unittest/s3utils/dir.baz/file.foo.bar",
+                "unittest/s3utils/dir.baz/file.foo.baz",
+                "unittest/s3utils/dir.baz/file.bar.baz",
+                "unittest/s3utils/dir.foo/file.bar",
+                "unittest/s3utils/dir.foo/file.baz",
+                "unittest/s3utils/dir.foo/file.foo",
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_s3_listfile)
     @ddt.unpack
     def test_s3_listfile(self, src, bucket, prefix, include_patterns, exclude_patterns, depth, expect):
         with moto.mock_aws(), s3_make_client(region_name="us-east-1") as client:
@@ -200,142 +202,144 @@ class S3UtilsTest(unittest.TestCase):
             self.assertSetEqual(set(map(lambda x: norm_path(x.key), object_metas)),
                                 set(map(lambda x: norm_path(x), expect)))
 
-    @ddt.data(
+    data_s3_sync = [
         (
-            "{res_dir}/unittest/shutils/",
-            "{tmp_dir}/unittest/shutils/",
+            "{res_dir}/unittest/s3utils/",
+            "{tmp_dir}/unittest/s3utils/",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             [],
             [],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.bar.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.bar.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
-            "{tmp_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
+            "{tmp_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             [],
             [],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.bar.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.bar.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils/dir.foo",
-            "{tmp_dir}/unittest/shutils/dir.foo",
+            "{res_dir}/unittest/s3utils/dir.foo",
+            "{tmp_dir}/unittest/s3utils/dir.foo",
             "dummy-bucket",
-            "unittest/shutils/dir.foo",
+            "unittest/s3utils/dir.foo",
             [],
             [],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.bar.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/dir.foo.bar.baz/file.foo.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils/dir.baz",
-            "{tmp_dir}/unittest/shutils/dir.baz",
+            "{res_dir}/unittest/s3utils/dir.baz",
+            "{tmp_dir}/unittest/s3utils/dir.baz",
             "dummy-bucket",
-            "unittest/shutils/dir.baz",
+            "unittest/s3utils/dir.baz",
             [],
             [],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.bar.baz",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
-            "{tmp_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
+            "{tmp_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             ["*.foo", "*.bar"],
             ["*.foo.bar"],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
-            "{tmp_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
+            "{tmp_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             ["*.foo", "*.bar"],
             [],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
-            "{tmp_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
+            "{tmp_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils/",
+            "unittest/s3utils/",
             [],
             ["*.baz"],
             0,
             [
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
-                "{tmp_dir}/unittest/shutils/dir.foo/dir.foo.bar/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.foo/dir.foo.bar/file.foo.bar",
             ],
         ),
         (
-            "{res_dir}/unittest/shutils",
-            "{tmp_dir}/unittest/shutils",
+            "{res_dir}/unittest/s3utils",
+            "{tmp_dir}/unittest/s3utils",
             "dummy-bucket",
-            "unittest/shutils",
+            "unittest/s3utils",
             [],
             [],
             2,
             [
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.bar",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.foo.baz",
-                "{tmp_dir}/unittest/shutils/dir.baz/file.bar.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.bar",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.baz",
-                "{tmp_dir}/unittest/shutils/dir.foo/file.foo",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.bar",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.foo.baz",
+                "{tmp_dir}/unittest/s3utils/dir.baz/file.bar.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.bar",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.baz",
+                "{tmp_dir}/unittest/s3utils/dir.foo/file.foo",
             ],
         ),
-    )
+    ]
+
+    @ddt.idata(data_s3_sync)
     @ddt.unpack
     def test_s3_sync(self, src, dst, bucket, prefix, include_patterns, exclude_patterns, depth, expect):
         with moto.mock_aws(), s3_make_client(region_name="us-east-1") as client:
@@ -399,14 +403,16 @@ class S3UtilsTest(unittest.TestCase):
                 self.assertSetEqual(set(map(lambda x: norm_path(x), listfile(dst.format(tmp_dir=temp_directory)))),
                                     set(map(lambda x: norm_path(x.format(tmp_dir=temp_directory)), expect)))
 
-    @ddt.data(
+    data_s3_text = [
         ("dummy-bucket", "dummy/key", "dummy content", None),
         ("dummy-bucket", "dummy/key.alpha", "Old MacDonald had a farm", None),
         ("dummy-bucket", "dummy/key.beta", "Ee-i-ee-i-o", None),
         ("dummy-bucket", "dummy/key", "dummy content", "ascii"),
         ("dummy-bucket", "dummy/key.alpha", "Old MacDonald had a farm", "ascii"),
         ("dummy-bucket", "dummy/key.beta", "Ee-i-ee-i-o", "ascii"),
-    )
+    ]
+
+    @ddt.idata(data_s3_text)
     @ddt.unpack
     def test_s3_text(self, bucket, key, text, encoding):
         with moto.mock_aws(), s3_make_client(region_name="us-east-1") as client:
