@@ -9,7 +9,8 @@ from iker.common.utils.sequtils import Seq
 from iker.common.utils.sequtils import batch_yield
 from iker.common.utils.sequtils import chunk, chunk_between, chunk_with_key, merge_chunks
 from iker.common.utils.sequtils import deduped, grouped
-from iker.common.utils.sequtils import head, init, last, tail
+from iker.common.utils.sequtils import head, last
+from iker.common.utils.sequtils import init, init_iter, tail, tail_iter
 from iker.common.utils.sequtils import seq
 
 
@@ -23,10 +24,12 @@ class SeqUtilsTest(unittest.TestCase):
         self.assertEqual(expect, head(data))
 
     def test_head__empty(self):
-        self.assertRaises(Exception, head, [])
+        with self.assertRaises(Exception):
+            head([])
 
     def test_head__none(self):
-        self.assertRaises(Exception, head, None)
+        with self.assertRaises(Exception):
+            head(None)
 
     data_last = [([1], 1), ([1, 2], 2)]
 
@@ -36,10 +39,12 @@ class SeqUtilsTest(unittest.TestCase):
         self.assertEqual(expect, last(data))
 
     def test_last__empty(self):
-        self.assertRaises(Exception, last, [])
+        with self.assertRaises(Exception):
+            last([])
 
     def test_last__none(self):
-        self.assertRaises(Exception, last, None)
+        with self.assertRaises(Exception):
+            last(None)
 
     data_init = [([1], []), ([1, 2], [1]), ([1, 2, 3], [1, 2])]
 
@@ -51,8 +56,43 @@ class SeqUtilsTest(unittest.TestCase):
     def test_init__empty(self):
         self.assertEqual([], init([]))
 
+    def test_init__recursive(self):
+        self.assertEqual([1, 2, 3, 4], init([1, 2, 3, 4, 5]))
+        self.assertEqual([1, 2, 3], init(init([1, 2, 3, 4, 5])))
+        self.assertEqual([1, 2], init(init(init([1, 2, 3, 4, 5]))))
+        self.assertEqual([1], init(init(init(init([1, 2, 3, 4, 5])))))
+
     def test_init__none(self):
-        self.assertRaises(Exception, init, None)
+        with self.assertRaises(Exception):
+            init(None)
+
+    data_init_iter = [([1], []), ([1, 2], [1]), ([1, 2, 3], [1, 2])]
+
+    @ddt.idata(data_init_iter)
+    @ddt.unpack
+    def test_init_iter(self, data, expect):
+        self.assertEqual(expect, list(init_iter(data)))
+
+    def test_init_iter__empty(self):
+        self.assertEqual([], list(init_iter([])))
+
+    def test_init_iter__recursive(self):
+        self.assertEqual([1, 2, 3, 4], list(init_iter([1, 2, 3, 4, 5])))
+        self.assertEqual([1, 2, 3], list(init_iter(init_iter([1, 2, 3, 4, 5]))))
+        self.assertEqual([1, 2], list(init_iter(init_iter(init_iter([1, 2, 3, 4, 5])))))
+        self.assertEqual([1], list(init_iter(init_iter(init_iter(init_iter([1, 2, 3, 4, 5]))))))
+        self.assertEqual([], list(init_iter(init_iter(init_iter(init_iter(init_iter([1, 2, 3, 4, 5])))))))
+        self.assertEqual([], list(init_iter(init_iter(init_iter(init_iter(init_iter(init_iter([1, 2, 3, 4, 5]))))))))
+
+    def test_init_iter__with_iters(self):
+        self.assertEqual([2, 3, 4], list(init_iter(tail_iter([1, 2, 3, 4, 5]))))
+        self.assertEqual([5, 4, 3, 2], list(init_iter(reversed([1, 2, 3, 4, 5]))))
+        self.assertEqual([1, 2, 3, 4], list(init_iter(sorted([5, 4, 3, 2, 1]))))
+        self.assertEqual([2], list(init_iter(filter(lambda x: x % 2 == 0, [1, 2, 3, 4, 5]))))
+
+    def test_init_iter__none(self):
+        with self.assertRaises(Exception):
+            list(init_iter(None))
 
     data_tail = [([1], []), ([1, 2], [2]), ([1, 2, 3], [2, 3])]
 
@@ -64,8 +104,43 @@ class SeqUtilsTest(unittest.TestCase):
     def test_tail__empty(self):
         self.assertEqual([], tail([]))
 
+    def test_tail__recursive(self):
+        self.assertEqual([2, 3, 4, 5], tail([1, 2, 3, 4, 5]))
+        self.assertEqual([3, 4, 5], tail(tail([1, 2, 3, 4, 5])))
+        self.assertEqual([4, 5], tail(tail(tail([1, 2, 3, 4, 5]))))
+        self.assertEqual([5], tail(tail(tail(tail([1, 2, 3, 4, 5])))))
+
     def test_tail__none(self):
-        self.assertRaises(Exception, tail, None)
+        with self.assertRaises(Exception):
+            tail(None)
+
+    data_tail_iter = [([1], []), ([1, 2], [2]), ([1, 2, 3], [2, 3])]
+
+    @ddt.idata(data_tail_iter)
+    @ddt.unpack
+    def test_tail_iter(self, data, expect):
+        self.assertEqual(expect, list(tail_iter(data)))
+
+    def test_tail_iter__empty(self):
+        self.assertEqual([], list(tail_iter([])))
+
+    def test_tail_iter__recursive(self):
+        self.assertEqual([2, 3, 4, 5], list(tail_iter([1, 2, 3, 4, 5])))
+        self.assertEqual([3, 4, 5], list(tail_iter(tail_iter([1, 2, 3, 4, 5]))))
+        self.assertEqual([4, 5], list(tail_iter(tail_iter(tail_iter([1, 2, 3, 4, 5])))))
+        self.assertEqual([5], list(tail_iter(tail_iter(tail_iter(tail_iter([1, 2, 3, 4, 5]))))))
+        self.assertEqual([], list(tail_iter(tail_iter(tail_iter(tail_iter(tail_iter([1, 2, 3, 4, 5])))))))
+        self.assertEqual([], list(tail_iter(tail_iter(tail_iter(tail_iter(tail_iter(tail_iter([1, 2, 3, 4, 5]))))))))
+
+    def test_tail_iter__with_iters(self):
+        self.assertEqual([2, 3, 4], list(tail_iter(init_iter([1, 2, 3, 4, 5]))))
+        self.assertEqual([4, 3, 2, 1], list(tail_iter(reversed([1, 2, 3, 4, 5]))))
+        self.assertEqual([2, 3, 4, 5], list(tail_iter(sorted([5, 4, 3, 2, 1]))))
+        self.assertEqual([4], list(tail_iter(filter(lambda x: x % 2 == 0, [1, 2, 3, 4, 5]))))
+
+    def test_tail_iter__none(self):
+        with self.assertRaises(Exception):
+            list(tail_iter(None))
 
     data_grouped = [
         (None, lambda x: x, []),
@@ -1066,6 +1141,8 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [2, 4, 7, 11, 16]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [1, 2, 6, 24, 120]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [1, 12, 123, 1234, 12345]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: x + y, ["1", "12", "123", "1234", "12345"]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: y + x, ["1", "21", "321", "4321", "54321"]),
     ]
 
     @ddt.idata(data_scan_left)
@@ -1081,6 +1158,8 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16, 15, 13, 10, 6]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120, 120, 60, 20, 5]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [54321, 5432, 543, 54, 5]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: x + y, ["54321", "5432", "543", "54", "5"]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: y + x, ["12345", "2345", "345", "45", "5"]),
     ]
 
     @ddt.idata(data_scan_right)
@@ -1109,6 +1188,8 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [12345]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: x + y, ["12345"]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: y + x, ["54321"]),
     ]
 
     @ddt.idata(data_fold_left)
@@ -1123,6 +1204,8 @@ class SeqTest(unittest.TestCase):
         ([1, 2, 3, 4, 5], 1, lambda x, y: x + y, [16]),
         ([1, 2, 3, 4, 5], 1, lambda x, y: x * y, [120]),
         ([1, 2, 3, 4, 5], 0, lambda x, y: x * 10 + y, [54321]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: x + y, ["54321"]),
+        (["1", "2", "3", "4", "5"], "", lambda x, y: y + x, ["12345"]),
     ]
 
     @ddt.idata(data_fold_right)
